diff --git a/.gitattributes b/.gitattributes
index 10a562ecbc2d0ec583f01df3dfe2a4b0b33fd2a6..ddbb2ce3441206d7e1a21c365c064155ee68b473 100644
--- a/.gitattributes
+++ b/.gitattributes
@@ -2649,8 +2649,8 @@ RTCP/Storage/include/Storage/FastFileStream.h -text
 RTCP/Storage/include/Storage/Format.h -text
 RTCP/Storage/include/Storage/HDF5Attributes.h -text
 RTCP/Storage/include/Storage/IOPriority.h -text
+RTCP/Storage/include/Storage/MSWriterDAL.h -text
 RTCP/Storage/include/Storage/MSWriterFile.h -text
-RTCP/Storage/include/Storage/MSWriterLDA.h -text
 RTCP/Storage/include/Storage/MSWriterNull.h -text
 RTCP/Storage/include/Storage/MeasurementSetFormat.h -text
 RTCP/Storage/include/Storage/OutputThread.h -text
@@ -2668,8 +2668,8 @@ RTCP/Storage/src/TBB_Writer.cc -text
 RTCP/Storage/src/TBB_Writer_main.cc -text
 RTCP/Storage/src/gnuplotMS.sh -text
 RTCP/Storage/src/plotMS.cc -text
+RTCP/Storage/test/tDAL.cc -text
 RTCP/Storage/test/tFastFileStream.cc -text
-RTCP/Storage/test/tLDA.cc -text
 RTCP/Storage/test/tMeasurementSetFormat.parset-j2000 -text
 RTCP/Storage/test/tMeasurementSetFormat.parset-sun -text
 RTCP/Storage/test/tTBB_StaticMapping.cc -text
diff --git a/CMake/FindLDA.cmake b/CMake/FindLDA.cmake
deleted file mode 100644
index 4dd12c683aec8d45a440c1a2cf18760ae2c884ef..0000000000000000000000000000000000000000
--- a/CMake/FindLDA.cmake
+++ /dev/null
@@ -1,48 +0,0 @@
-# - Try to find LDA.
-# Variables used by this module:
-#  LDA_ROOT_DIR     - LDA root directory
-# Variables defined by this module:
-#  LDA_FOUND        - system has LDA
-#  LDA_INCLUDE_DIR  - the LDA include directory (cached)
-#  LDA_INCLUDE_DIRS - the LDA include directories
-#                       (identical to LDA_INCLUDE_DIR)
-#  LDA_LIBRARY      - the LDA library (cached)
-#  LDA_LIBRARIES    - the LDA libraries
-#                       (identical to LDA_LIBRARY)
-
-# Copyright (C) 2011
-# ASTRON (Netherlands Institute for Radio Astronomy)
-# P.O.Box 2, 7990 AA Dwingeloo, The Netherlands
-#
-# This file is part of the LOFAR software suite.
-# The LOFAR software suite is free software: you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as published
-# by the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# The LOFAR software suite is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along
-# with the LOFAR software suite. If not, see <http://www.gnu.org/licenses/>.
-#
-# $Id$
-
-if(NOT LDA_FOUND)
-
-  find_path(LDA_INCLUDE_DIR lda_config.h
-    HINTS ${LDA_ROOT_DIR} PATH_SUFFIXES include/lda)
-  find_library(LDA_LIBRARY lda
-    HINTS ${LDA_ROOT_DIR} PATH_SUFFIXES lib)
-  mark_as_advanced(LDA_INCLUDE_DIR LDA_LIBRARY)
-
-  include(FindPackageHandleStandardArgs)
-  find_package_handle_standard_args(LDA DEFAULT_MSG 
-    LDA_LIBRARY LDA_INCLUDE_DIR)
-
-  set(LDA_INCLUDE_DIRS ${LDA_INCLUDE_DIR})
-  set(LDA_LIBRARIES ${LDA_LIBRARY})
-
-endif(NOT LDA_FOUND)
diff --git a/CMake/variants/variants.lhn001 b/CMake/variants/variants.lhn001
index 72dcf6dd183b9108bbc7b5b344193150f4e96160..f1537d404fbda605d770d9d7b333b19fed737aa9 100644
--- a/CMake/variants/variants.lhn001
+++ b/CMake/variants/variants.lhn001
@@ -2,7 +2,7 @@ option(BUILD_SHARED_LIBS        "Build shared libraries"      ON)
 
 set(CASACORE_ROOT_DIR /opt/cep/casacore)
 set(CASAREST_ROOT_DIR /opt/cep/casarest)
-set(LDA_ROOT_DIR /opt/cep/lda)
+set(DAL_ROOT_DIR /globalhome/lofarsystem/packages/root/lhn/dal)
 set(ENV{HDF5_ROOT} /opt/cep/storage/hdf5)
 
 set(PYRAP_ROOT_DIR /opt/cep/pyrap)
diff --git a/RTCP/Run/src/RTCP.parset b/RTCP/Run/src/RTCP.parset
index e5b906b712c5f07023d95b5c12d3a94fe386ea5a..2584988ca000c2843f949fed33c56023cb80ad5c 100644
--- a/RTCP/Run/src/RTCP.parset
+++ b/RTCP/Run/src/RTCP.parset
@@ -8,7 +8,7 @@ Observation.Campaign.name = "Development"
 Observation.Campaign.title = "Development"
 
 # ----- Input streams
-Observation.VirtualInstrument.stationList = [CS302]
+Observation.VirtualInstrument.stationList = [S9,S10]
 #Observation.antennaSet=LBA_INNER
 #Observation.antennaSet=LBA_OUTER
 #Observation.antennaSet=LBA_X
@@ -19,7 +19,8 @@ Observation.VirtualInstrument.stationList = [CS302]
 #Observation.antennaSet=HBA_ONE
 #Observation.antennaSet=HBA_DUAL
 #Observation.antennaSet=HBA_JOINED
-Observation.antennaSet=LBA_INNER
+#Observation.antennaSet=LBA_INNER
+Observation.antennaSet=
 
 OLAP.realTime = T # T when reading data from stations, F when reading from disk
 
@@ -32,7 +33,7 @@ OLAP.nrTimesInFrame = 16
 #     [ 3*(0;1;2;3)  ] --> [ 0,1,2,3,0,1,2,3,0,1,2,3 ]
 #     [ 3*(300..303) ] --> [ 300,301,302,303,300,301,302,303,300,301,302,303 ]
 #     [ 2*(5*0)      ] --> [ 0,0,0,0,0,0,0,0,0,0 ]       
-Observation.subbandList  = [100..343]
+Observation.subbandList  = [100..102]
 Observation.sampleClock  = 200
 OLAP.nrBitsPerSample     = 16
 
diff --git a/RTCP/Run/src/deploy/Makefile b/RTCP/Run/src/deploy/Makefile
index 8d3e14cd5a32eaac88282c451511eadcd4e04206..a3b38cca2c88dac83d6b5a045f836d13efc181a6 100644
--- a/RTCP/Run/src/deploy/Makefile
+++ b/RTCP/Run/src/deploy/Makefile
@@ -76,8 +76,7 @@ COMMON_FLAGS += -DLOFAR_SVN_UPDATE=ON -DBUILD_TESTING=OFF
 ION_FLAGS +=
 CN_FLAGS +=
 BGFEN_FLAGS += -DUSE_LOG4CPLUS=ON
-#STORAGE_FLAGS += -DLDA_ROOT_DIR=/globalhome/lofarsystem/packages/root/lhn/lda -DUSE_MPI=OFF -DUSE_LOG4CPLUS=ON -DUSE_DAL=ON
-STORAGE_FLAGS += -DLDA_ROOT_DIR=/opt/cep/lda -DUSE_MPI=OFF -DUSE_LOG4CPLUS=ON
+STORAGE_FLAGS += -DDAL_ROOT_DIR=/globalhome/lofarsystem/packages/root/lhn/lda -DUSE_MPI=OFF -DUSE_LOG4CPLUS=ON
 
 # Extra powers for Storage_main
 STORAGE_CAPABILITIES = cap_sys_admin,cap_sys_nice,cap_ipc_lock
diff --git a/RTCP/Storage/CMakeLists.txt b/RTCP/Storage/CMakeLists.txt
index e21bbd5e5b1e395d5d0f8d77d050a4866f7bb54e..4388dc440aa8dc1d885a7c98d909afc252d6014e 100644
--- a/RTCP/Storage/CMakeLists.txt
+++ b/RTCP/Storage/CMakeLists.txt
@@ -4,7 +4,7 @@ lofar_package(Storage 1.0 DEPENDS Common ApplCommon Interface MSLofar LofarStMan
 
 include(LofarFindPackage)
 lofar_find_package(Casacore COMPONENTS casa measures ms tables REQUIRED)
-lofar_find_package(LDA REQUIRED)
+lofar_find_package(DAL REQUIRED)
 lofar_find_package(HDF5 REQUIRED)
 
 add_subdirectory(include/Storage)
diff --git a/RTCP/Storage/src/OutputThread.cc b/RTCP/Storage/src/OutputThread.cc
index 73de63beca20af5aa52e8ce4e2fdc078232a31bc..ddefbccbef7b538caf694b71c0b276fb9dd916d3 100644
--- a/RTCP/Storage/src/OutputThread.cc
+++ b/RTCP/Storage/src/OutputThread.cc
@@ -25,7 +25,7 @@
 
 #include <Common/StringUtil.h>
 #include <Storage/MSWriterFile.h>
-#include <Storage/MSWriterLDA.h>
+#include <Storage/MSWriterDAL.h>
 #include <Storage/MSWriterNull.h>
 #include <Storage/MeasurementSetFormat.h>
 #include <Storage/OutputThread.h>
@@ -159,7 +159,7 @@ void OutputThread::createMS()
     // HDF5 writer requested
     switch (itsOutputType) {
       case BEAM_FORMED_DATA:
-        itsWriter = new MSWriterLDA<float,3>(path.c_str(), itsParset, itsStreamNr, itsIsBigEndian);
+        itsWriter = new MSWriterDAL<float,3>(path.c_str(), itsParset, itsStreamNr, itsIsBigEndian);
         break;
       default:
         itsWriter = new MSWriterFile(path, itsOutputType == BEAM_FORMED_DATA);
diff --git a/RTCP/Storage/test/CMakeLists.txt b/RTCP/Storage/test/CMakeLists.txt
index 1d55472e2682e4c18af6e88a4971a70b3f047283..d6e49b8ccb3c65decfbb69171d30c08a748fdfc4 100644
--- a/RTCP/Storage/test/CMakeLists.txt
+++ b/RTCP/Storage/test/CMakeLists.txt
@@ -3,7 +3,7 @@
 include(LofarCTest)
 
 lofar_add_test(tMeasurementSetFormat tMeasurementSetFormat.cc)
-#lofar_add_test(tLDA tLDA.cc)
+#lofar_add_test(tDAL tDAL.cc)
 lofar_add_test(tFastFileStream tFastFileStream.cc)
 #lofar_add_test(tAH_TestStorage tAH_TestStorage.cc)
 #lofar_add_test(tTBB_StaticMapping tTBB_StaticMapping.cc)
diff --git a/lofar_config.h.cmake b/lofar_config.h.cmake
index 54cb374ec7e75828e7e77cea62d7f25911e23935..2303c2e747f42200271004bc9059324ae69088d5 100644
--- a/lofar_config.h.cmake
+++ b/lofar_config.h.cmake
@@ -120,9 +120,6 @@
 /* Define if LAM is installed */
 #cmakedefine HAVE_LAM 1
 
-/* Define if LDA is installed */
-#cmakedefine HAVE_LDA
-
 /* Define if LOG4CPLUS is installed */
 #cmakedefine HAVE_LOG4CPLUS 1
diff --git a/RTCP/Storage/include/Storage/MSWriterLDA.h b/RTCP/Storage/include/Storage/MSWriterDAL.h
similarity index 82%
rename from RTCP/Storage/include/Storage/MSWriterLDA.h
rename to RTCP/Storage/include/Storage/MSWriterDAL.h
index 9f2985c7431c0887274a2da31ee244d96398e466..4dc58b3ab35d813598e565e548dc669957915579 100644
--- a/RTCP/Storage/include/Storage/MSWriterLDA.h
+++ b/RTCP/Storage/include/Storage/MSWriterDAL.h
@@ -1,4 +1,4 @@
 //  MSMriterLDA.h: implementation of MSWriter using the LDA to write HDF5
 //
 //  Copyright (C) 2011
 //  ASTRON (Netherlands Foundation for Research in Astronomy)
@@ -18,13 +18,13 @@
 //  along with this program; if not, write to the Free Software
 //  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 //
-//  $Id: MSWriterLDA.h 11891 2011-10-14 13:43:51Z gels $
+//  $Id: MSWriterDAL.h 11891 2011-10-14 13:43:51Z gels $
 //
 //////////////////////////////////////////////////////////////////////
 
 
-#ifndef LOFAR_STORAGE_MSWRITERLDA_H
-#define LOFAR_STORAGE_MSWRITERLDA_H
+#ifndef LOFAR_STORAGE_MSWRITERDAL_H
+#define LOFAR_STORAGE_MSWRITERDAL_H
 
 //# Includes
 #include <Common/LofarTypes.h>
@@ -42,11 +42,11 @@ namespace LOFAR
 
   namespace RTCP
   {
-    template<typename T, unsigned DIM> class MSWriterLDA : public MSWriterFile
+    template<typename T, unsigned DIM> class MSWriterDAL : public MSWriterFile
     {
     public:
-      MSWriterLDA(const string &filename, const Parset &parset, unsigned fileno, bool isBigEndian);
-      ~MSWriterLDA();
+      MSWriterDAL(const string &filename, const Parset &parset, unsigned fileno, bool isBigEndian);
+      ~MSWriterDAL();
       virtual void write(StreamableData *data);
     private:
       const Transpose2 &itsTransposeLogic;
@@ -1,4 +1,4 @@
-//  MSMriterLDA.h: implementation of MSWriter using the LDA to write HDF5
+//  MSMriterDAL.h: implementation of MSWriter using the DAL to write HDF5
 //
 //  Copyright (C) 2011
diff --git a/RTCP/Storage/src/MSWriterLDA.cc b/RTCP/Storage/src/MSWriterLDA.cc
index 5ca09d6c687feae1b3f43b7952fe08a41ad25a1b..9a1cb2c04a48b8b604ed326d0491c300f9056847 100644
--- a/RTCP/Storage/src/MSWriterLDA.cc
+++ b/RTCP/Storage/src/MSWriterLDA.cc
@@ -1,4 +1,4 @@
 //# MSWriterLDA: an implementation of MSWriter using the LDA to write HDF5
 //#
 //#  Copyright (C) 2011
 //#  ASTRON (Netherlands Foundation for Research in Astronomy)
@@ -26,11 +26,11 @@
 #include <Common/SystemUtil.h>
 
 #include <Storage/MSWriter.h>
-#include <Storage/MSWriterLDA.h>
+#include <Storage/MSWriterDAL.h>
 
 #include <lofar/BF_File.h>
 
-using namespace LDA;
+using namespace DAL;
 using namespace std;
 
 #include <Common/Thread/Mutex.h>
@@ -101,7 +101,7 @@ namespace LOFAR
     // uses global locks too anyway.
     static Mutex HDF5Mutex;
 
-    template <typename T,unsigned DIM> MSWriterLDA<T,DIM>::MSWriterLDA (const string &filename, const Parset &parset, unsigned fileno, bool isBigEndian)
+    template <typename T,unsigned DIM> MSWriterDAL<T,DIM>::MSWriterDAL (const string &filename, const Parset &parset, unsigned fileno, bool isBigEndian)
     :
       MSWriterFile(forceextension(string(filename),".raw"),false),
       itsTransposeLogic(parset.transposeLogic()),
@@ -157,11 +157,11 @@ namespace LOFAR
           break;
 
         case INVALID_STOKES:
-          LOG_ERROR("MSWriterLDA asked to write INVALID_STOKES");
+          LOG_ERROR("MSWriterDAL asked to write INVALID_STOKES");
           return;
       }    
 
-      LOG_DEBUG_STR("MSWriterLDA: opening " << filename);
+      LOG_DEBUG_STR("MSWriterDAL: opening " << filename);
 
       // create the top structure
       BF_File file(h5filename, BF_File::CREATE);
@@ -408,11 +408,11 @@ namespace LOFAR
       stokesDS.nofSamples()     .set(dims[0]);
     }
 
-    template <typename T,unsigned DIM> MSWriterLDA<T,DIM>::~MSWriterLDA()
+    template <typename T,unsigned DIM> MSWriterDAL<T,DIM>::~MSWriterDAL()
     {
     }
 
-    template <typename T,unsigned DIM> void MSWriterLDA<T,DIM>::write(StreamableData *data)
+    template <typename T,unsigned DIM> void MSWriterDAL<T,DIM>::write(StreamableData *data)
     {
       SampleData<T,DIM> *sdata = dynamic_cast<SampleData<T,DIM> *>(data);
 
@@ -434,7 +434,7 @@ namespace LOFAR
     }
 
     // specialisation for FinalBeamFormedData
-    template class MSWriterLDA<float,3>;
+    template class MSWriterDAL<float,3>;
 
   } // namespace RTCP
 } // namespace LOFAR
@@ -1,4 +1,4 @@
-//# MSWriterLDA: an implementation of MSWriter using the LDA to write HDF5
+//# MSWriterDAL: an implementation of MSWriter using the DAL to write HDF5
 //#
 //#  Copyright (C) 2011
diff --git a/RTCP/Storage/test/tLDA.cc b/RTCP/Storage/test/tDAL.cc
similarity index 83%
rename from RTCP/Storage/test/tLDA.cc
rename to RTCP/Storage/test/tDAL.cc
index 53abe7338ae4691060c0b9c6b70c054f30913023..a687b6dd96c057778ed40e6e0a2acf7cf0db98be 100644
--- a/RTCP/Storage/test/tLDA.cc
+++ b/RTCP/Storage/test/tDAL.cc
@@ -1,4 +1,4 @@
 //# tLDA: Test HDF5 routines through LDA
 //#
 //#  Copyright (C) 2011
 //#  ASTRON (Netherlands Foundation for Research in Astronomy)
@@ -22,18 +22,18 @@
 
 #include <lofar_config.h>
 
-#ifdef HAVE_LDA
+#ifdef HAVE_DAL
 
-#include <lda_version.h>
+#include <dal_version.h>
 #include <iostream>
 #include <string>
 
 using namespace std;
-using namespace LDA;
+using namespace DAL;
 
 int main() {
   if (!check_hdf5_versions()) {
-    cerr << "HDF5 version mismatch. LDA was compiled with " << get_lda_hdf5_version() << ", our headers are " << get_current_hdf5_header_version() << ", our library is " << get_current_hdf5_lib_version() << endl;
+    cerr << "HDF5 version mismatch. DAL was compiled with " << get_dal_hdf5_version() << ", our headers are " << get_current_hdf5_header_version() << ", our library is " << get_current_hdf5_lib_version() << endl;
     return 1;
   }
   
@@ -1,4 +1,4 @@
-//# tLDA: Test HDF5 routines through LDA
+//# tDAL: Test HDF5 routines through DAL
 //#
 //#  Copyright (C) 2011